        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
}
