        function getR(rrw){
           cx=0;
       cx+=1;
       if(rrw==cx){return 5;}
       cx+=1;
       if(rrw==cx){return 40;}
       cx+=1;
       if(rrw==cx){return 41;}
       cx+=1;
       if(rrw==cx){return 42;}
       cx+=1;
       if(rrw==cx){return 43;}
return -1;}
