        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
}
