        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 21 <strong>control</strong><br>0,2,6,7,9,11,13,14,16,18,19,25,28,29,30,33,34,36,38,46,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 15 <br>3,4,10,12,15,17,20,31,35,37,39,41,44,45,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>1</strong> miembros: 15 <br>1,5,8,21,22,23,24,26,27,32,40,42,43,47,48';}
}
